import { AddressFormatter } from "./types";
/**
 * Rule 1 - No building name, number or sub building name
 * No premise elements detected (typically organisation name)
 */
export declare const rule1: AddressFormatter;
/**
 * Rule 2 - Building number only
 */
export declare const rule2: AddressFormatter;
/**
 * Rule 3 - Building name only
 *
 * Check format of Building Name (see note (a) above). If the Exception
 * Rule applies, the Building Name should appear at the beginning of the
 * first Thoroughfare line, or the first Locality line if there is no
 * Thoroughfare information.
 *
 * When a building has a name AND a number range, both must be held in the
 * Building Name field because the Building Number field can only hold numeric
 * characters.
 *
 * If an address has a building name with text followed by a space and then
 * completed by numerics/numeric ranges with the numeric part an exception
 * (see Note (a) above), the numerics/numeric range are treated as a building
 * number, and the text part is treated as the Building Name and the
 * numerics/numeric range are split off to appear at the beginning of the first
 * Thoroughfare line, or the first Locality line if there is no Thoroughfare.
 */
export declare const rule3: AddressFormatter;
/**
 * Rule 4 - Building Name and Number
 *
 * The Building Name should appear on the line preceding the Thoroughfare
 * and/or Locality information. The Building Number should appear at the
 * beginning of the first Thoroughfare line. If there is no Thoroughfare
 * information then the Building Number should appear at the beginning of
 * the first Locality line.
 */
export declare const rule4: AddressFormatter;
/**
 * Rule 5 - Sub Building Name and Building Number
 *
 * The Sub Building Name should appear on the line preceding the Thoroughfare
 * and Locality information. The Building Number should appear at the beginning
 * of the first Thoroughfare line. If there is no Thoroughfare information then
 * the Building Number should appear at the beginning of the first Locality line.
 */
export declare const rule5: AddressFormatter;
/**
 * Rule 6 - Sub building name and building name
 *
 * Check the format of Sub Building Name (see Note (a) above). If the Exception
 * Rule applies, the Sub Building Name should appear on the same line as, and
 * before, the Building Name.
 *
 * Otherwise, the Sub Building Name should appear on a line preceding the Building
 * Name, Thoroughfare and Locality information
 *
 * Check format of Building Name (see note (a) above) If the Exception Rule applies,
 * the Building Name should appear at the beginning of the first Thoroughfare line,
 * or the first Locality line if there is no Thoroughfare information. Otherwise, the
 * Building Name should appear on a line preceding the Thoroughfare and Locality information.
 */
export declare const rule6: AddressFormatter;
/**
 * Rule 7 - Sub building name, building name and building number
 *
 * If the Exception Rule applies, the Sub Building Name should appear on the same
 * line as and before the Building Name.
 */
export declare const rule7: AddressFormatter;
/**
 * Undocumented Rule
 *
 * This rule should not exist as it is not listed in the developer docs. But some records
 * in the wild only have a sub building name
 */
export declare const undocumentedRule: AddressFormatter;
/**
 * PO Box Rule
 */
export declare const po_box: AddressFormatter;
export declare const formatter: AddressFormatter;
