"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const utils_1 = require("./utils");
const koelle_sort_1 = require("@cablanchard/koelle-sort");
const sortingElems = [
    "building_number",
    "building_name",
    "sub_building_name",
    "organisation_name",
    "department_name",
    "po_box",
];
/**
 * Takes an `Address` instance and returns a building number, first checking for
 * name exceptions in building_name and sub_building_name fields
 */
const extractIntegerAttribute = (a) => {
    if (utils_1.nameException(a.building_name))
        return a.building_name;
    if (utils_1.nameException(a.sub_building_name))
        return a.sub_building_name;
    return a.building_number;
};
/**
 * Sorts `Address` objects based on the precedence outlined in `sortingElems`
 */
exports.sort = (a, b) => {
    for (const attr of sortingElems) {
        let A, B;
        if (attr === "building_number") {
            A = extractIntegerAttribute(a);
            B = extractIntegerAttribute(b);
        }
        else {
            A = a[attr];
            B = b[attr];
        }
        if (A === B)
            continue;
        return koelle_sort_1.alphanum(A, B);
    }
    return 0;
};
//# sourceMappingURL=sort.js.map